bio-attention.positional Reference
===============

Here be modules for adding positional encodings / biases to attention modules

.. autoclass:: bio_attention.positional.Sinusoidal
   :members:

.. autoclass:: bio_attention.positional.LearnedVocab
   :members:

.. autoclass:: bio_attention.positional.LearnedContinuous
   :members:

.. autoclass:: bio_attention.positional.Rotary
   :members:

.. autoclass:: bio_attention.positional.ALiBi
   :members:

.. autoclass:: bio_attention.positional.DPB
   :members:

.. autoclass:: bio_attention.positional.XL
   :members: